@@ -1,11 +1,10 @@
 from pydantic.main import BaseModel
 import requests
 from learning_loop_node.converter.converter import Converter
-from learning_loop_node.status import TrainingStatus
+from learning_loop_node.status import TrainingStatus, State
 from learning_loop_node.context import Context
 from learning_loop_node.node import Node
 import asyncio
-from status import State
 from fastapi.encoders import jsonable_encoder
 from fastapi_utils.tasks import repeat_every
 from icecream import ic
@@ -67,3 +66,7 @@ class ConverterNode(Node):
                     ic(model)
                     if self.converter.source_format in model['formats'] and not self.converter.target_format in model['formats']:
                         return ModelInformation(organization=organization_id, project=project_id, model_id=model['id'])
+
+    async def send_status(self):
+        # NOTE not yet implemented
+        pass
\ No newline at end of file
